.. _torchani-publications:

.. currentmodule:: torchani

Publications
============

The general architecture of ANI-style models was originally proposed in the `ANI`_
article. You can read more about the models that TorchANI implements in the `ANI-1x`_,
`ANI-2x`_, `ANI-1ccx`_ and `ANI-2x`_ articles. The original publication for the library
is `TorchANI`_, and the current version is `TorchANI3`_.


.. _TorchANI3:
    https://TODO

.. _TorchANI:
    https://doi.org/10.26434/chemrxiv.12218294.v1

.. _ANI:
    http://pubs.rsc.org/en/Content/ArticleLanding/2017/SC/C6SC05720A#!divAbstract

.. _ANI-1:
    https://www.nature.com/articles/sdata2017193

.. _ANI-1x:
    https://aip.scitation.org/doi/abs/10.1063/1.5023802

.. _ANI-1ccx:
    https://doi.org/10.26434/chemrxiv.6744440.v1

.. _ANI-2x:
    https://doi.org/10.26434/chemrxiv.11819268.v1
